@@ -4,8 +4,8 @@ Dist <- function(x, method="euclidean", diag=FALSE, upper=FALSE)
     if(!is.na(pmatch(method, "euclidian")))
 	method <- "euclidean"
 
-    METHODS <- c("euclidean", "maximum",
-                 "manhattan", "canberra", "binary","pearson","correlation")
+    METHODS <- c("euclidean", "maximum", "manhattan", "canberra",
+                 "binary","pearson","correlation","spearman")
     method <- pmatch(method, METHODS)
     if(is.na(method))
 	stop("invalid distance method")
@@ -34,4 +34,3 @@ Dist <- function(x, method="euclidean", diag=FALSE, upper=FALSE)
     class(d) <- "dist"
     return(d)
 }
-
